Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(74)

Unified Diff: chrome/browser/ssl/chrome_ssl_host_state_delegate.h

Issue 2244253002: Rename |pid| to |child_id| in SSLHostStateDelegate (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 4 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ssl/chrome_ssl_host_state_delegate.h
diff --git a/chrome/browser/ssl/chrome_ssl_host_state_delegate.h b/chrome/browser/ssl/chrome_ssl_host_state_delegate.h
index b958a1daa4888847b68983d755a583f08daf6d97..782344a275621b2b6cefd3159864fa51111a1b31 100644
--- a/chrome/browser/ssl/chrome_ssl_host_state_delegate.h
+++ b/chrome/browser/ssl/chrome_ssl_host_state_delegate.h
@@ -39,11 +39,11 @@ class ChromeSSLHostStateDelegate : public content::SSLHostStateDelegate {
net::CertStatus error,
bool* expired_previous_decision) override;
void HostRanInsecureContent(const std::string& host,
- int pid,
+ int child_id,
InsecureContentType content_type) override;
bool DidHostRunInsecureContent(
const std::string& host,
- int pid,
+ int child_id,
InsecureContentType content_type) const override;
// Revokes all SSL certificate error allow exceptions made by the user for
@@ -111,7 +111,7 @@ class ChromeSSLHostStateDelegate : public content::SSLHostStateDelegate {
RememberSSLExceptionDecisionsDisposition should_remember_ssl_decisions_;
Profile* profile_;
// A BrokenHostEntry is a pair of (host, process_id) that indicates the host
// contains insecure content in that renderer process.
typedef std::pair<std::string, int> BrokenHostEntry;
« no previous file with comments | « android_webview/browser/aw_ssl_host_state_delegate.cc ('k') | chrome/browser/ssl/chrome_ssl_host_state_delegate.cc » ('j') | no next file with comments »
@@ -111,7 +111,7 @@ class ChromeSSLHostStateDelegate : public content::SSLHostStateDelegate {
RememberSSLExceptionDecisionsDisposition should_remember_ssl_decisions_;
Profile* profile_;
- // A BrokenHostEntry is a pair of (host, process_id) that indicates the host
+ // A BrokenHostEntry is a pair of (host, child_id) that indicates the host
// contains insecure content in that renderer process.
typedef std::pair<std::string, int> BrokenHostEntry;

Powered by Google App Engine
This is Rietveld 408576698